@@ -16,6 +16,7 @@
 
 #include <QAction>
 #include <QMenu>
+#include <QProcess>
 #include <QUrl>
 
 #include <KConfig>
@@ -25,7 +26,6 @@
 #include <KMessageBox>
 #include <KPluginFactory>
 #include <KPluginLoader>
-#include <KProcess>
 
 std::unique_ptr<QStringList> s_pHistory;
 
@@ -78,7 +78,7 @@ QList<QAction*> KDiff3FileItemAction::actions(const KFileItemListProperties& fil
     //m_fileItemInfos = fileItemInfos;
     m_pParentWidget = pParentWidget;
 
-    QAction* pMenuAction = new QAction(QIcon::fromTheme(QStringLiteral("kdiff3")), i18n("KDiff3..."), this);
+    QAction* pMenuAction = new QAction(QIcon::fromTheme(QStringLiteral("kdiff3")), i18nc("Contexualmenu title", "KDiff3..."), this);
     QMenu* pActionMenu = new QMenu();
     pMenuAction->setMenu(pActionMenu);
 
@@ -103,32 +103,32 @@ QList<QAction*> KDiff3FileItemAction::actions(const KFileItemListProperties& fil
     {
         QtSizeType historyCount = s_pHistory ? s_pHistory->count() : 0;
 
-        actionText = i18n("Compare with %1", (historyCount > 0 ? s_pHistory->first() : QString()));
+        actionText = i18nc("Contexualmenu option", "Compare with %1", (historyCount > 0 ? s_pHistory->first() : QString()));
         pAction = new QAction(actionText, this);
         connect(pAction, &QAction::triggered, this, &KDiff3FileItemAction::slotCompareWith);
         pAction->setEnabled(m_list.count() > 0 && historyCount > 0);
         pActionMenu->addAction(pAction);
 
-        actionText = i18n("Merge with %1", historyCount > 0 ? s_pHistory->first() : QString());
+        actionText = i18nc("Contexualmenu option", "Merge with %1", historyCount > 0 ? s_pHistory->first() : QString());
         pAction = new QAction(actionText, this);
         connect(pAction, &QAction::triggered, this, &KDiff3FileItemAction::slotMergeWith);
         pAction->setEnabled(m_list.count() > 0 && historyCount > 0);
         pActionMenu->addAction(pAction);
 
-        actionText = i18n("Save '%1' for later", m_list.first().fileName());
+        actionText = i18nc("Contexualmenu option", "Save '%1' for later", m_list.first().fileName());
         pAction = new QAction(actionText, this);
         connect(pAction, &QAction::triggered, this, &KDiff3FileItemAction::slotSaveForLater);
         pAction->setEnabled(m_list.count() > 0);
         pActionMenu->addAction(pAction);
 
-        pAction = new QAction(i18n("3-way merge with base"), this);
+        pAction = new QAction(i18nc("Contexualmenu option", "3-way merge with base"), this);
         connect(pAction, &QAction::triggered, this, &KDiff3FileItemAction::slotMergeThreeWay);
         pAction->setEnabled(m_list.count() > 0 && historyCount >= 2);
         pActionMenu->addAction(pAction);
 
         if(s_pHistory && !s_pHistory->empty())
         {
-            QAction* pHistoryMenuAction = new QAction(i18n("Compare with..."), this);
+            QAction* pHistoryMenuAction = new QAction(i18nc("Contexualmenu option", "Compare with..."), this);
             QMenu* pHistoryMenu = new QMenu();
             pHistoryMenuAction->setMenu(pHistoryMenu);
             pHistoryMenu->setEnabled(m_list.count() > 0 && historyCount > 0);
@@ -149,17 +149,17 @@ QList<QAction*> KDiff3FileItemAction::actions(const KFileItemListProperties& fil
     }
     else if(m_list.count() == 2)
     {
-        pAction = new QAction(i18nc("Contexualmenu option ", "Compare"), this);
+        pAction = new QAction(i18nc("Contexualmenu option", "Compare"), this);
         connect(pAction, &QAction::triggered, this, &KDiff3FileItemAction::slotCompareTwoFiles);
         pActionMenu->addAction(pAction);
     }
     else if(m_list.count() == 3)
     {
-        pAction = new QAction(i18n("3 way comparison"), this);
+        pAction = new QAction(i18nc("Contexualmenu option", "3 way comparison"), this);
         connect(pAction, &QAction::triggered, this, &KDiff3FileItemAction::slotCompareThreeFiles);
         pActionMenu->addAction(pAction);
     }
-    pAction = new QAction(i18n("About KDiff3 menu plugin..."), this);
+    pAction = new QAction(i18nc("Contexualmenu option", "About KDiff3 menu plugin..."), this);
     connect(pAction, &QAction::triggered, this, &KDiff3FileItemAction::slotAbout);
     pActionMenu->addAction(pAction);
 
@@ -180,7 +180,7 @@ void KDiff3FileItemAction::slotCompareWith()
             s_pHistory->first(),
             Utils::urlToString(m_list.first())
         };
-        KProcess::startDetached("kdiff3", args);
+        QProcess::startDetached("kdiff3", args);
     }
 }
 
@@ -193,7 +193,7 @@ void KDiff3FileItemAction::slotCompareWithHistoryItem()
             pAction->data().toString(),
             Utils::urlToString(m_list.first())
         };
-        KProcess::startDetached("kdiff3", args);
+        QProcess::startDetached("kdiff3", args);
     }
 }
 
@@ -205,7 +205,7 @@ void KDiff3FileItemAction::slotCompareTwoFiles()
             Utils::urlToString(m_list.first()),
             Utils::urlToString(m_list.last())
         };
-        KProcess::startDetached("kdiff3", args);
+        QProcess::startDetached("kdiff3", args);
     }
 }
 
@@ -218,7 +218,7 @@ void KDiff3FileItemAction::slotCompareThreeFiles()
             Utils::urlToString(m_list.at(1)),
             Utils::urlToString(m_list.at(2))
         };
-        KProcess::startDetached("kdiff3", args);
+        QProcess::startDetached("kdiff3", args);
     }
 }
 
@@ -231,7 +231,7 @@ void KDiff3FileItemAction::slotMergeWith()
             Utils::urlToString(m_list.first()),
             ("-o" + Utils::urlToString(m_list.first()))
         };
-        KProcess::startDetached("kdiff3", args);
+        QProcess::startDetached("kdiff3", args);
     }
 }
 
@@ -245,7 +245,7 @@ void KDiff3FileItemAction::slotMergeThreeWay()
             Utils::urlToString(m_list.first()),
             ("-o" + Utils::urlToString(m_list.first()))
         };
-        KProcess::startDetached("kdiff3", args);
+        QProcess::startDetached("kdiff3", args);
     }
 }
 
