@@ -1,3 +1,4 @@
+// clang-format off
 /*
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -162,7 +163,7 @@ void MergeFileInfos::sort(Qt::SortOrder order)
 {
     std::sort(m_children.begin(), m_children.end(), MfiCompare(order));
 
-    for(int i = 0; i < m_children.count(); ++i)
+    for(qint32 i = 0; i < m_children.count(); ++i)
         m_children[i]->sort(order);
 }
 
@@ -217,7 +218,7 @@ bool MergeFileInfos::compareFilesAndCalcAges(QStringList& errors, QSharedPointer
                 existsInC() ? getFileInfoC()->absoluteFilePath() : QString(""),
                 "",
                 "", "", "", &diffStatus());
-            int nofNonwhiteConflicts = diffStatus().getNonWhitespaceConflicts();
+            qint32 nofNonwhiteConflicts = diffStatus().getNonWhitespaceConflicts();
 
             if(pOptions->m_bDmWhiteSpaceEqual && nofNonwhiteConflicts == 0)
             {
@@ -287,7 +288,7 @@ bool MergeFileInfos::compareFilesAndCalcAges(QStringList& errors, QSharedPointer
     assert(eNew == 0 && eMiddle == 1 && eOld == 2);
 
     // The map automatically sorts the keys.
-    int age = eNew;
+    qint32 age = eNew;
     std::map<QDateTime, FilesFound>::reverse_iterator i;
     for(i = dateMap.rbegin(); i != dateMap.rend(); ++i)
     {
@@ -375,7 +376,7 @@ bool MergeFileInfos::fastFileComparison(
     FileAccess& fi1, FileAccess& fi2,
     bool& bError, QString& status, const QSharedPointer<const Options> &pOptions)
 {
-    ProgressProxy pp;
+    ProgressScope pp;
     bool bEqual = false;
 
     status = "";
@@ -474,14 +475,14 @@ bool MergeFileInfos::fastFileComparison(
         return bEqual;
     }
     qCInfo(kdiffMergeFileInfo) << "Comparing files...";
-    pp.setInformation(i18n("Comparing file..."), 0, false);
+    ProgressProxy::setInformation(i18n("Comparing file..."), 0, false);
     typedef qint64 t_FileSize;
     t_FileSize fullSize = fi1.size();
     t_FileSize sizeLeft = fullSize;
 
-    pp.setMaxNofSteps(fullSize / buf1.size());
+    ProgressProxy::setMaxNofSteps(fullSize / buf1.size());
 
-    while(sizeLeft > 0 && !pp.wasCancelled())
+    while(sizeLeft > 0 && !ProgressProxy::wasCancelled())
     {
         qint64 len = std::min(sizeLeft, (t_FileSize)buf1.size());
         if(len != fi1.read(&buf1[0], len))
@@ -508,8 +509,8 @@ bool MergeFileInfos::fastFileComparison(
             return bEqual;
         }
         sizeLeft -= len;
-        //pp.setCurrent(double(fullSize-sizeLeft)/fullSize, false );
-        pp.step();
+        //ProgressProxy::setCurrent(double(fullSize-sizeLeft)/fullSize, false );
+        ProgressProxy::step();
     }
     fi1.close();
     fi2.close();
@@ -566,7 +567,7 @@ QTextStream& operator<<(QTextStream& ts, MergeFileInfos& mfi)
     vm.writeEntry("EqualAC", mfi.isEqualAC());
     vm.writeEntry("EqualBC", mfi.isEqualBC());
 
-    vm.writeEntry("MergeOperation", (int)mfi.getOperation());
+    vm.writeEntry("MergeOperation", (qint32)mfi.getOperation());
     vm.writeEntry("DirA", mfi.isDirA());
     vm.writeEntry("DirB", mfi.isDirB());
     vm.writeEntry("DirC", mfi.isDirC());
@@ -575,9 +576,9 @@ QTextStream& operator<<(QTextStream& ts, MergeFileInfos& mfi)
     vm.writeEntry("LinkC", mfi.isLinkC());
     vm.writeEntry("OperationComplete", !mfi.isOperationRunning());
 
-    vm.writeEntry("AgeA", (int)mfi.getAgeA());
-    vm.writeEntry("AgeB", (int)mfi.getAgeB());
-    vm.writeEntry("AgeC", (int)mfi.getAgeC());
+    vm.writeEntry("AgeA", (qint32)mfi.getAgeA());
+    vm.writeEntry("AgeB", (qint32)mfi.getAgeB());
+    vm.writeEntry("AgeC", (qint32)mfi.getAgeC());
     vm.writeEntry("ConflictingAges", mfi.conflictingAges()); // Equal age but files are not!
 
     vm.save(ts);
