@@ -69,7 +69,6 @@ void Options::init()
     addOptionItem(std::make_shared<OptionToggleAction>(false, "WindowStateFullScreen", &m_bFullScreen));
     addOptionItem(std::make_shared<OptionToggleAction>(false, "WindowStateMaximised", &m_bMaximised));
 
-    addOptionItem(std::make_shared<OptionToggleAction>(true, "Show Toolbar", &m_bShowToolBar));
     addOptionItem(std::make_shared<OptionToggleAction>(true, "Show Statusbar", &m_bShowStatusBar));
 
     //Options in Options dialog.
@@ -107,11 +106,11 @@ void Options::readOptions(const KSharedConfigPtr config)
 
     read(&cvm);
 
-    if(m_whiteSpace2FileMergeDefault <= (int)e_SrcSelector::Min)
-        m_whiteSpace2FileMergeDefault = (int)e_SrcSelector::None;
+    if(m_whiteSpace2FileMergeDefault <= (qint32)e_SrcSelector::Min)
+        m_whiteSpace2FileMergeDefault = (qint32)e_SrcSelector::None;
 
-    if(m_whiteSpace2FileMergeDefault > (int)e_SrcSelector::Max)
-        m_whiteSpace2FileMergeDefault = (int)e_SrcSelector::C;
+    if(m_whiteSpace2FileMergeDefault > (qint32)e_SrcSelector::Max)
+        m_whiteSpace2FileMergeDefault = (qint32)e_SrcSelector::C;
 }
 
 const QString Options::parseOptions(const QStringList& optionList)
@@ -120,7 +119,7 @@ const QString Options::parseOptions(const QStringList& optionList)
 
     for(const QString& optionString: optionList)
     {
-        int pos = optionString.indexOf('=');
+        qint32 pos = optionString.indexOf('=');
         if(pos > 0) // seems not to have a tag
         {
             const QString key = optionString.left(pos);
