@@ -1,3 +1,4 @@
+// clang-format off
 /*
  *  This file is part of KDiff3.
  *
@@ -5,34 +6,35 @@
  * SPDX-FileCopyrightText: 2018-2020 Michael Reeves reeves.87@gmail.com
  * SPDX-License-Identifier: GPL-2.0-or-later
 */
+// clang-format on
 
 #ifndef SOURCEDATA_H
 #define SOURCEDATA_H
 
-#include "options.h"
+#include "diff.h"
 #include "fileaccess.h"
 #include "LineRef.h"
+#include "options.h"
 
-#include <boost/signals2.hpp>
+#include <memory>
 
 #include <QTextCodec>
 #include <QTemporaryFile>
+#include <QSharedPointer>
 #include <QString>
-#include <QVector>
+#include <QStringList>
 
-class LineData;
 class SourceData
 {
   public:
-    void setupConnections();
     void setOptions(const QSharedPointer<Options> &pOptions);
 
-    Q_REQUIRED_RESULT LineRef getSizeLines() const;
+    Q_REQUIRED_RESULT LineCount getSizeLines() const;
     Q_REQUIRED_RESULT qint64 getSizeBytes() const;
     Q_REQUIRED_RESULT const char* getBuf() const;
     Q_REQUIRED_RESULT const QString& getText() const;
-    Q_REQUIRED_RESULT const QVector<LineData>* getLineDataForDisplay() const;
-    Q_REQUIRED_RESULT const QVector<LineData>* getLineDataForDiff() const;
+    Q_REQUIRED_RESULT const std::shared_ptr<LineDataVector>& getLineDataForDisplay() const;
+    Q_REQUIRED_RESULT const std::shared_ptr<LineDataVector>& getLineDataForDiff() const;
 
     void setFilename(const QString& filename);
     void setFileAccess(const FileAccess& fileAccess);
@@ -59,17 +61,19 @@ class SourceData
 
     Q_REQUIRED_RESULT QTextCodec* getEncoding() const { return m_pEncoding; }
     Q_REQUIRED_RESULT e_LineEndStyle getLineEndStyle() const { return m_normalData.m_eLineEndStyle; }
+    [[nodiscard]] inline bool hasEOLTermiantion() { return m_normalData.hasEOLTermiantion(); }
+
 
     Q_REQUIRED_RESULT const QStringList& getErrors() const { return mErrors; }
 
     void setEncoding(QTextCodec* pEncoding);
 
-  private:
+  protected:
     bool convertFileEncoding(const QString& fileNameIn, QTextCodec* pCodecIn,
                                 const QString& fileNameOut, QTextCodec* pCodecOut);
 
     static QTextCodec* dectectUTF8(const QByteArray& data);
-    static QTextCodec* detectEncoding(const char* buf, qint64 size, qint64& skipBytes);
+    static QTextCodec* detectEncoding(const char* buf, qint64 size, FileOffset& skipBytes);
     static QTextCodec* getEncodingFromTag(const QByteArray& s, const QByteArray& encodingTag);
 
     QTextCodec* detectEncoding(const QString& fileName, QTextCodec* pFallbackCodec);
@@ -87,18 +91,17 @@ class SourceData
     {
       private:
         friend SourceData;
-        const char* m_pBuf = nullptr; //TODO: Phase out needlessly wastes memory and time by keeping second copy of file data.
-        qint64 mDataSize = 0;
+        std::unique_ptr<char[]> m_pBuf; //TODO: Phase out needlessly wastes memory and time by keeping second copy of file data.
+        quint64 mDataSize = 0;
         qint64 mLineCount = 0; // Number of lines in m_pBuf1 and size of m_v1, m_dv12 and m_dv13
         QSharedPointer<QString> m_unicodeBuf=QSharedPointer<QString>::create();
-        QVector<LineData> m_v;
+        std::shared_ptr<LineDataVector> m_v=std::make_shared<LineDataVector>();
         bool m_bIsText = false;
         bool m_bIncompleteConversion = false;
         e_LineEndStyle m_eLineEndStyle = eLineEndStyleUndefined;
+        bool mHasEOLTermination = false;
 
       public:
-        ~FileData() { reset(); }
-
         bool readFile(FileAccess& file);
         bool readFile(const QString& filename);
         bool writeFile(const QString& filename);
@@ -107,21 +110,17 @@ class SourceData
         void reset();
         void copyBufFrom(const FileData& src);
 
-        bool isEmpty() const { return mDataSize == 0; }
+        [[nodiscard]] bool isEmpty() const { return mDataSize == 0; }
 
-        bool isText() const { return m_bIsText || isEmpty(); }
+        [[nodiscard]] bool isText() const { return m_bIsText || isEmpty(); }
+        [[nodiscard]] inline bool hasEOLTermiantion() { return m_bIsText && mHasEOLTermination; }
 
-        inline qint64 lineCount() const { return mLineCount; }
-        inline qint64 byteCount() const { return mDataSize; }
+        [[nodiscard]] inline qint64 lineCount() const { return mLineCount; }
+        [[nodiscard]] inline qint64 byteCount() const { return mDataSize; }
     };
     FileData m_normalData;
     FileData m_lmppData;
     QTextCodec* m_pEncoding = nullptr;
-
-    /*
-      This list exists solely to auto disconnect boost signals.
-    */
-    std::list<boost::signals2::scoped_connection> connections;
 };
 
 #endif // !SOURCEDATA_H
