@@ -21,6 +21,7 @@
 #include <cstdlib>
 #include <ctype.h>
 #include <memory>
+#include <optional>
 #include <utility>             // for swap
 
 #ifndef AUTOTEST
@@ -36,11 +37,11 @@ constexpr bool g_bIgnoreWhiteSpace = true;
 
 QSharedPointer<DiffBufferInfo> Diff3Line::m_pDiffBufferInfo = QSharedPointer<DiffBufferInfo>::create();
 
-int LineData::width(int tabSize) const
+qint32 LineData::width(qint32 tabSize) const
 {
     const QString pLine = getLine();
-    int w = 0;
-    int j = 0;
+    qint32 w = 0;
+    qint32 j = 0;
     for(QtSizeType i = 0; i < size(); ++i)
     {
         if(pLine[i] == '\t')
@@ -58,6 +59,34 @@ int LineData::width(int tabSize) const
     return w;
 }
 
+class StringIter {
+    QString::const_iterator ptr;
+    QString::const_iterator end;
+
+public:
+    StringIter(QString const& s)
+        : ptr(s.begin())
+        , end(s.end())
+    {}
+
+    bool hasPeek() const {
+        return ptr < end;
+    }
+
+    std::optional<QChar> tryPeek() const {
+        if (ptr < end) {
+            return *ptr;
+        } else {
+            return {};
+        }
+    }
+
+    void next() {
+        assert(ptr < end);
+        ptr++;
+    }
+};
+
 /*
     Implement support for g_bIgnoreWhiteSpace
 */
@@ -69,21 +98,30 @@ bool LineData::equal(const LineData& l1, const LineData& l2)
     {
         // Ignore white space diff
         const QString line1 = l1.getLine(), line2 = l2.getLine();
-        QString::const_iterator p1 = line1.begin();
-        QString::const_iterator p1End = line1.end();
-        QString::const_iterator p2 = line2.begin();
-        QString::const_iterator p2End = line2.end();
+        StringIter p1{line1};
+        StringIter p2{line2};
 
-        for(; p1 != p1End && p2 != p2End; p1++, p2++)
+        for(; ; p1.next(), p2.next())
         {
-            while(isspace(p1->unicode()) && p1 != p1End) ++p1;
-            while(isspace(p2->unicode()) && p2 != p2End) ++p2;
+            // Advance to the next non-whitespace character or EOL.
+            while (p1.hasPeek() && isspace(p1.tryPeek()->toLatin1())) {
+                p1.next();
+            }
+            while (p2.hasPeek() && isspace(p2.tryPeek()->toLatin1())) {
+                p2.next();
+            }
 
-            if(*p1 != *p2)
+            // If the two strings differ outside of whitespace, or either ends earlier, return false.
+            if(p1.tryPeek() != p2.tryPeek())
                 return false;
-        }
 
-        return (p1 == p1End && p2 == p2End);
+            // If both strings end together, return true.
+            if (!p1.hasPeek() && !p2.hasPeek()) {
+                return true;
+            }
+
+            // Test remaining characters.
+        }
     }
     else
     {
@@ -292,7 +330,7 @@ void Diff3LineList::calcDiff3LineListUsingBC(const DiffList* pDiffListBC)
                 if(i3c1 == i3b && !i3b->isEqualAB()) // i3c before i3b
                 {
                     Diff3LineList::iterator i3 = i3c;
-                    int nofDisturbingLines = 0;
+                    qint32 nofDisturbingLines = 0;
                     while(i3 != i3b && i3 != end())
                     {
                         if(i3->getLineB().isValid())
@@ -368,7 +406,7 @@ void Diff3LineList::calcDiff3LineListUsingBC(const DiffList* pDiffListBC)
                 else if(i3b1 == i3c && !i3c->isEqualAC())
                 {
                     Diff3LineList::iterator i3 = i3b;
-                    int nofDisturbingLines = 0;
+                    qint32 nofDisturbingLines = 0;
                     while(i3 != i3c && i3 != end())
                     {
                         if(i3->getLineC().isValid())
@@ -487,7 +525,7 @@ void Diff3LineList::calcDiff3LineListUsingBC(const DiffList* pDiffListBC)
     }
     /*
    Diff3LineList::iterator it = d3ll.begin();
-   int li=0;
+   qint32 li=0;
    for( ; it!=d3ll.end(); ++it, ++li )
    {
       printf( "%4d %4d %4d %4d  A%c=B A%c=C B%c=C\n",
@@ -589,7 +627,7 @@ bool ManualDiffHelpEntry::isValidMove(LineRef line1, LineRef line2, e_SrcSelecto
     return true;
 }
 
-int ManualDiffHelpEntry::calcManualDiffFirstDiff3LineIdx(const Diff3LineVector& d3lv)
+qint32 ManualDiffHelpEntry::calcManualDiffFirstDiff3LineIdx(const Diff3LineVector& d3lv)
 {
     QtSizeType i;
     for(i = 0; i < d3lv.size(); ++i)
@@ -598,7 +636,7 @@ int ManualDiffHelpEntry::calcManualDiffFirstDiff3LineIdx(const Diff3LineVector&
         if((lineA1.isValid() && lineA1 == d3l->getLineA()) ||
            (lineB1.isValid() && lineB1 == d3l->getLineB()) ||
            (lineC1.isValid() && lineC1 == d3l->getLineC()))
-            return SafeInt<int>(i);
+            return SafeInt<qint32>(i);
     }
     return -1;
 }
@@ -606,10 +644,10 @@ int ManualDiffHelpEntry::calcManualDiffFirstDiff3LineIdx(const Diff3LineVector&
 void DiffList::runDiff(const std::shared_ptr<LineDataVector> &p1, const size_t index1, LineRef size1, const std::shared_ptr<LineDataVector> &p2, const size_t index2, LineRef size2,
                     const QSharedPointer<Options> &pOptions)
 {
-    ProgressProxy pp;
+    ProgressScope pp;
     static GnuDiff gnuDiff; // All values are initialized with zeros.
 
-    pp.setCurrent(0);
+    ProgressProxy::setCurrent(0);
 
     clear();
     if(p1->empty() || (*p1)[index1].getBuffer() == nullptr || p2->empty() || (*p2)[index2].getBuffer() == nullptr || size1 == 0 || size2 == 0)
@@ -687,7 +725,7 @@ void DiffList::runDiff(const std::shared_ptr<LineDataVector> &p1, const size_t i
 
     verify(size1, size2);
 
-    pp.setCurrent(1);
+    ProgressProxy::setCurrent(1);
 }
 
 // Verify difflist
@@ -718,8 +756,8 @@ void ManualDiffHelpList::runDiff(const std::shared_ptr<LineDataVector> &p1, Line
     diffList.clear();
     DiffList diffList2;
 
-    int l1begin = 0;
-    int l2begin = 0;
+    qint32 l1begin = 0;
+    qint32 l2begin = 0;
     ManualDiffHelpList::const_iterator i;
     for(i = begin(); i != end(); ++i)
     {
@@ -765,7 +803,7 @@ void Diff3LineList::correctManualDiffAlignment(ManualDiffHelpList* pManualDiffHe
     {
         Diff3LineList::iterator i3 = begin();
         e_SrcSelector missingWinIdx = e_SrcSelector::None;
-        int alignedSum = (!iMDHL->getLine1(e_SrcSelector::A).isValid() ? 0 : 1) + (!iMDHL->getLine1(e_SrcSelector::B).isValid() ? 0 : 1) + (!iMDHL->getLine1(e_SrcSelector::C).isValid() ? 0 : 1);
+        qint32 alignedSum = (!iMDHL->getLine1(e_SrcSelector::A).isValid() ? 0 : 1) + (!iMDHL->getLine1(e_SrcSelector::B).isValid() ? 0 : 1) + (!iMDHL->getLine1(e_SrcSelector::C).isValid() ? 0 : 1);
         if(alignedSum == 2)
         {
             // If only A & B are aligned then let C rather be aligned with A
@@ -927,10 +965,10 @@ void Diff3LineList::calcDiff3LineListTrim(
     Diff3LineList::iterator i3B = begin();
     Diff3LineList::iterator i3C = begin();
 
-    int line = 0;  // diff3line counters
-    int lineA = 0; //
-    int lineB = 0;
-    int lineC = 0;
+    qint32 line = 0;  // diff3line counters
+    qint32 lineA = 0; //
+    qint32 lineB = 0;
+    qint32 lineC = 0;
 
     ManualDiffHelpList::iterator iMDHL = pManualDiffHelpList->begin();
     // The iterator lookAhead is the variable line look ahead.
@@ -1074,7 +1112,7 @@ void Diff3LineList::calcDiff3LineListTrim(
         {
             // Empty space for A and B. A matches B, but not C. Move A & B up.
             Diff3LineList::iterator i = lineA > lineB ? i3A : i3B;
-            int l = lineA > lineB ? lineA : lineB;
+            qint32 l = lineA > lineB ? lineA : lineB;
 
             if(pManualDiffHelpList->isValidMove(i->getLineC(), lookAhead->getLineA(), e_SrcSelector::C, e_SrcSelector::A) &&
                pManualDiffHelpList->isValidMove(i->getLineC(), lookAhead->getLineB(), e_SrcSelector::C, e_SrcSelector::B))
@@ -1104,7 +1142,7 @@ void Diff3LineList::calcDiff3LineListTrim(
         {
             // Empty space for A and C. A matches C, but not B. Move A & C up.
             Diff3LineList::iterator i = lineA > lineC ? i3A : i3C;
-            int l = lineA > lineC ? lineA : lineC;
+            qint32 l = lineA > lineC ? lineA : lineC;
 
             if(pManualDiffHelpList->isValidMove(i->getLineB(), lookAhead->getLineA(), e_SrcSelector::B, e_SrcSelector::A) &&
                pManualDiffHelpList->isValidMove(i->getLineB(), lookAhead->getLineC(), e_SrcSelector::B, e_SrcSelector::C))
@@ -1134,7 +1172,7 @@ void Diff3LineList::calcDiff3LineListTrim(
         {
             // Empty space for B and C. B matches C, but not A. Move B & C up.
             Diff3LineList::iterator i = lineB > lineC ? i3B : i3C;
-            int l = lineB > lineC ? lineB : lineC;
+            qint32 l = lineB > lineC ? lineB : lineC;
             if(pManualDiffHelpList->isValidMove(i->getLineA(), lookAhead->getLineB(), e_SrcSelector::A, e_SrcSelector::B) &&
                pManualDiffHelpList->isValidMove(i->getLineA(), lookAhead->getLineC(), e_SrcSelector::A, e_SrcSelector::C))
             {
@@ -1185,7 +1223,7 @@ void Diff3LineList::calcDiff3LineListTrim(
     /*
 
    Diff3LineList::iterator it = d3ll.begin();
-   int li=0;
+   qint32 li=0;
    for( ; it!=d3ll.end(); ++it, ++li )
    {
       printf( "%4d %4d %4d %4d  A%c=B A%c=C B%c=C\n",
@@ -1220,7 +1258,7 @@ void Diff3LineList::calcWhiteDiff3Lines(
 /*
     Builds DiffList for scratch. Automaticly clears all previous data in list.
 */
-void DiffList::calcDiff(const QString& line1, const QString& line2, const int maxSearchRange)
+void DiffList::calcDiff(const QString& line1, const QString& line2, const qint32 maxSearchRange)
 {
     clear();
 
@@ -1236,7 +1274,7 @@ void DiffList::calcDiff(const QString& line1, const QString& line2, const int ma
      */
     for(; size() * sizeof(Diff) + sizeof(DiffList) < (50 << 20);)
     {
-        int nofEquals = 0;
+        qint32 nofEquals = 0;
         while(p1 != line1.cend() && p2 != line2.cend() && *p1 == *p2)
         {
             ++p1;
@@ -1245,10 +1283,10 @@ void DiffList::calcDiff(const QString& line1, const QString& line2, const int ma
         }
 
         bool bBestValid = false;
-        int bestI1 = 0;
-        int bestI2 = 0;
-        int i1 = 0;
-        int i2 = 0;
+        qint32 bestI1 = 0;
+        qint32 bestI2 = 0;
+        qint32 i1 = 0;
+        qint32 i2 = 0;
 
         for(i1 = 0;; ++i1)
         {
@@ -1276,7 +1314,7 @@ void DiffList::calcDiff(const QString& line1, const QString& line2, const int ma
                 }
             }
             //Bail this should never happen. Not a nice exit but acts as a back stop against harder to detect infine looping.
-            if(i1 == TYPE_MAX(int))
+            if(i1 == TYPE_MAX(qint32))
             {
                 assert(false);
                 abort();
@@ -1316,7 +1354,7 @@ void DiffList::calcDiff(const QString& line1, const QString& line2, const int ma
         // a match where later actually equal parts don't match anymore.
         // A different match could be achieved, if we start at the end.
         // Do it, if it would be a better match.
-        int nofUnmatched = 0;
+        qint32 nofUnmatched = 0;
         QString::const_iterator pu1 = p1 - 1;
         QString::const_iterator pu2 = p2 - 1;
 
@@ -1399,7 +1437,7 @@ bool Diff3Line::fineDiff(bool inBTextsTotalEqual, const e_SrcSelector selector,
 {
     LineRef k1 = 0;
     LineRef k2 = 0;
-    int maxSearchLength = 500;
+    qint32 maxSearchLength = 500;
     bool bTextsTotalEqual = inBTextsTotalEqual;
     bool bIgnoreComments = eIgnoreFlags & IgnoreFlag::ignoreComments;
     bool bIgnoreWhiteSpace = eIgnoreFlags & IgnoreFlag::ignoreWhiteSpace;
@@ -1523,17 +1561,15 @@ void Diff3Line::getLineInfo(const e_SrcSelector winIdx, const bool isTriple, Lin
 bool Diff3LineList::fineDiff(const e_SrcSelector selector, const std::shared_ptr<LineDataVector> &v1, const std::shared_ptr<LineDataVector> &v2, const IgnoreFlags eIgnoreFlags)
 {
     // Finetuning: Diff each line with deltas
-    ProgressProxy pp;
+    ProgressScope pp;
     bool bTextsTotalEqual = true;
     size_t listSize = size();
-    pp.setMaxNofSteps(listSize);
-    int listIdx = 0;
+    ProgressProxy::setMaxNofSteps(listSize);
 
     for(Diff3Line &diff: *this)
     {
         bTextsTotalEqual = diff.fineDiff(bTextsTotalEqual, selector, v1, v2, eIgnoreFlags);
-        ++listIdx;
-        pp.step();
+        ProgressProxy::step();
     }
     return bTextsTotalEqual;
 }
@@ -1579,7 +1615,7 @@ void Diff3LineList::debugLineCheck(const LineCount size, const e_SrcSelector src
                                    i18n("Severe Internal Error"));
                 #endif
 
-                qCCritical(kdiffMain) << "Severe Internal Error." << " line != i for srcSelector=" << (int)srcSelector << "\n";
+                qCCritical(kdiffMain) << "Severe Internal Error." << " line != i for srcSelector=" << (qint32)srcSelector << "\n";
                 ::exit(-1);
             }
             ++i;
