@@ -3,23 +3,14 @@
    Modified for KDiff3 by Joachim Eibl 2003.
    The original file was part of GNU DIFF.
 
-   Copyright (C) 1990-1999, 2000, 2002 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
-
-#include <sys/types.h>
+    Part of KDiff3 - Text Diff And Merge Tool
+   
+    SPDX-FileCopyrightText: 1988-2002 Free Software Foundation, Inc.
+    SPDX-FileCopyrightText: 2002-2011 Joachim Eibl, joachim.eibl at gmx.de
+    SPDX-FileCopyrightText: 2018-2020 Michael Reeves reeves.87@gmail.com
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <stdlib.h>
 #include <string.h>
@@ -30,9 +21,9 @@
 
 #include "gnudiff_diff.h"
 /* If non NULL, call this function when memory is exhausted. */
-void (*xalloc_fail_func)(void) = nullptr;
+void (*xalloc_fail_func)() = nullptr;
 
-void GnuDiff::xalloc_die(void)
+void GnuDiff::xalloc_die()
 {
     if(xalloc_fail_func)
         (*xalloc_fail_func)();
