@@ -65,7 +65,7 @@ class ReversibleScrollBar : public QScrollBar
 {
     Q_OBJECT
     bool* m_pbRightToLeftLanguage;
-    int m_realVal;
+    qint32 m_realVal;
 
   public:
     ReversibleScrollBar(Qt::Orientation o, bool* pbRightToLeftLanguage)
@@ -77,7 +77,7 @@ class ReversibleScrollBar : public QScrollBar
     }
     void setAgain() { setValue(m_realVal); }
 
-    void setValue(int i)
+    void setValue(qint32 i)
     {
         if(m_pbRightToLeftLanguage != nullptr && *m_pbRightToLeftLanguage)
             QScrollBar::setValue(maximum() - (i - minimum()));
@@ -85,12 +85,12 @@ class ReversibleScrollBar : public QScrollBar
             QScrollBar::setValue(i);
     }
 
-    [[nodiscard]] int value() const
+    [[nodiscard]] qint32 value() const
     {
         return m_realVal;
     }
   public Q_SLOTS:
-    void slotValueChanged(int i)
+    void slotValueChanged(qint32 i)
     {
         m_realVal = i;
         if(m_pbRightToLeftLanguage != nullptr && *m_pbRightToLeftLanguage)
@@ -99,7 +99,7 @@ class ReversibleScrollBar : public QScrollBar
     }
 
   Q_SIGNALS:
-    void valueChanged2(int);
+    void valueChanged2(qint32);
 };
 
 /*
@@ -235,9 +235,6 @@ public Q_SLOTS:
     /** paste the clipboard into the document
      */
     void slotEditPaste();
-    /** toggles the toolbar
-     */
-    void slotViewToolBar();
     /** toggles the statusbar
      */
     void slotViewStatusBar();
@@ -246,16 +243,16 @@ public Q_SLOTS:
      */
     void slotStatusMsg(const QString& text);
 
-    void resizeDiffTextWindowHeight(int newHeight);
+    void resizeDiffTextWindowHeight(qint32 newHeight);
     void slotRecalcWordWrap();
     void postRecalcWordWrap();
-    void slotFinishRecalcWordWrap(int visibleTextWidth);
+    void slotFinishRecalcWordWrap(qint32 visibleTextWidth);
 
     void showPopupMenu(const QPoint& point);
 
-    void scrollDiffTextWindow(int deltaX, int deltaY);
-    void scrollMergeResultWindow(int deltaX, int deltaY);
-    void sourceMask(int srcMask, int enabledMask);
+    void scrollDiffTextWindow(qint32 deltaX, qint32 deltaY);
+    void scrollMergeResultWindow(qint32 deltaX, qint32 deltaY);
+    void sourceMask(qint32 srcMask, qint32 enabledMask);
 
     void slotDirShowBoth();
     void slotDirViewToggle();
@@ -345,7 +342,7 @@ public Q_SLOTS:
 
     [[nodiscard]] QStatusBar* statusBar() const;
     [[nodiscard]] KToolBar* toolBar(const QLatin1String &toolBarId) const;
-    void recalcWordWrap(int visibleTextWidthForPrinting = -1);
+    void recalcWordWrap(qint32 visibleTextWidthForPrinting = -1);
 
     bool canCut();
     bool canCopy();
@@ -421,9 +418,9 @@ public Q_SLOTS:
     QWidget* m_pMergeWindowFrame = nullptr;
     ReversibleScrollBar* m_pHScrollBar = nullptr;
 
-    std::shared_ptr<DiffTextWindow> m_pDiffTextWindow1;
-    std::shared_ptr<DiffTextWindow> m_pDiffTextWindow2;
-    std::shared_ptr<DiffTextWindow> m_pDiffTextWindow3;
+    QPointer<DiffTextWindow> m_pDiffTextWindow1;
+    QPointer<DiffTextWindow> m_pDiffTextWindow2;
+    QPointer<DiffTextWindow> m_pDiffTextWindow3;
     DiffTextWindowFrame* m_pDiffTextWindowFrame1 = nullptr;
     DiffTextWindowFrame* m_pDiffTextWindowFrame2 = nullptr;
     DiffTextWindowFrame* m_pDiffTextWindowFrame3 = nullptr;
@@ -461,8 +458,8 @@ public Q_SLOTS:
     //ManualDiffHelpDialog* m_pManualDiffHelpDialog;
     ManualDiffHelpList m_manualDiffHelpList;
 
-    SafeInt<QtNumberType> m_neededLines = 0;
-    int m_DTWHeight = 0;
+    SafeInt<qint32> m_neededLines = 0;
+    qint32 m_DTWHeight = 0;
     bool m_bOutputModified = false;
     bool m_bFileSaved = false;
     bool m_bTimerBlock = false; // Synchronization
@@ -480,7 +477,7 @@ public Q_SLOTS:
     bool m_bAutoMode = false;
     bool m_bRecalcWordWrapPosted = false;
 
-    int m_firstD3LIdx = 0; // only needed during recalcWordWrap
+    qint32 m_firstD3LIdx = 0; // only needed during recalcWordWrap
     QPointer<QEventLoop> m_pEventLoopForPrinting;
 
     bool mRunnablesStarted = false;
