@@ -51,19 +51,9 @@
 #include <KParts/MainWindow>
 #include <KShortcutsDialog>
 
-// Function uses setMinSize( sizeHint ) before adding the widget.
-// void addWidget(QBoxLayout* layout, QWidget* widget);
-template <class W, class L>
-void addWidget(L* layout, W* widget)
-{
-    QSize s = widget->sizeHint();
-    widget->setMinimumSize(QSize(std::max(s.width(), 0), std::max(s.height(), 0)));
-    layout->addWidget(widget);
-}
-
 void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFlags)
 {
-    ProgressProxy pp;
+    ProgressScope pp;
     QStringList errors;
     // When doing a full analysis in the directory-comparison, then the statistics-results
     // will be stored in the given TotalDiffStatus. Otherwise pTotalDiffStatus will
@@ -94,7 +84,7 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
         if(bVisibleMergeResultWindow && !m_pOptions->m_PreProcessorCmd.isEmpty())
         {
             QString msg = "- " + i18n("PreprocessorCmd: ") + m_pOptions->m_PreProcessorCmd + '\n';
-            int result = KMessageBox::warningYesNo(this,
+            qint32 result = KMessageBox::warningYesNo(this,
                 i18n("The following option(s) you selected might change data:\n") + msg +
                     i18n("\nMost likely this is not wanted during a merge.\n"
                          "Do you want to disable these settings or continue with these settings active?"),
@@ -127,12 +117,12 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
         m_manualDiffHelpList.clear();
 
         if(m_sd3->isEmpty())
-            pp.setMaxNofSteps(4); // Read 2 files, 1 comparison, 1 finediff
+            ProgressProxy::setMaxNofSteps(4); // Read 2 files, 1 comparison, 1 finediff
         else
-            pp.setMaxNofSteps(9); // Read 3 files, 3 comparisons, 3 finediffs
+            ProgressProxy::setMaxNofSteps(9); // Read 3 files, 3 comparisons, 3 finediffs
 
         // First get all input data.
-        pp.setInformation(i18n("Loading A"));
+        ProgressProxy::setInformation(i18n("Loading A"));
         qCInfo(kdiffMain) << i18n("Loading A: %1", m_sd1->getFilename());
 
         if(bUseCurrentEncoding)
@@ -140,9 +130,9 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
         else
             m_sd1->readAndPreprocess(m_pOptions->m_pEncodingA, m_pOptions->m_bAutoDetectUnicodeA);
 
-        pp.step();
+        ProgressProxy::step();
 
-        pp.setInformation(i18n("Loading B"));
+        ProgressProxy::setInformation(i18n("Loading B"));
         qCInfo(kdiffMain) << i18n("Loading B: %1", m_sd2->getFilename());
 
         if(bUseCurrentEncoding)
@@ -150,16 +140,16 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
         else
             m_sd2->readAndPreprocess(m_pOptions->m_pEncodingB, m_pOptions->m_bAutoDetectUnicodeB);
 
-        pp.step();
+        ProgressProxy::step();
         errors.append(m_sd1->getErrors());
         errors.append(m_sd2->getErrors());
     }
     else
     {
         if(m_sd3->isEmpty())
-            pp.setMaxNofSteps(2); // 1 comparison, 1 finediff
+            ProgressProxy::setMaxNofSteps(2); // 1 comparison, 1 finediff
         else
-            pp.setMaxNofSteps(6); // 3 comparisons, 3 finediffs
+            ProgressProxy::setMaxNofSteps(6); // 3 comparisons, 3 finediffs
     }
 
     pTotalDiffStatus->reset();
@@ -173,33 +163,33 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
 
             if(m_sd1->isText() && m_sd2->isText())
             {
-                pp.setInformation(i18n("Diff: A <-> B"));
+                ProgressProxy::setInformation(i18n("Diff: A <-> B"));
                 qCInfo(kdiffMain) << i18n("Diff: A <-> B");
                 m_manualDiffHelpList.runDiff(m_sd1->getLineDataForDiff(), m_sd1->getSizeLines(), m_sd2->getLineDataForDiff(), m_sd2->getSizeLines(), m_diffList12, e_SrcSelector::A, e_SrcSelector::B,
                                              m_pOptionDialog->getOptions());
 
-                pp.step();
+                ProgressProxy::step();
 
-                pp.setInformation(i18n("Linediff: A <-> B"));
+                ProgressProxy::setInformation(i18n("Linediff: A <-> B"));
                 qCInfo(kdiffMain) << i18n("Linediff: A <-> B");
                 m_diff3LineList.calcDiff3LineListUsingAB(&m_diffList12);
 
                 pTotalDiffStatus->setTextEqualAB(m_diff3LineList.fineDiff(e_SrcSelector::A, m_sd1->getLineDataForDisplay(), m_sd2->getLineDataForDisplay(), eIgnoreFlags));
                 if(m_sd1->getSizeBytes() == 0) pTotalDiffStatus->setTextEqualAB(false);
 
-                pp.step();
+                ProgressProxy::step();
             }
             else
             {
-                pp.step();
-                pp.step();
+                ProgressProxy::step();
+                ProgressProxy::step();
             }
         }
         else
         {
             if(bLoadFiles)
             {
-                pp.setInformation(i18n("Loading C"));
+                ProgressProxy::setInformation(i18n("Loading C"));
                 qCInfo(kdiffMain) << i18n("Loading C: %1", m_sd3->getFilename());
 
                 if(bUseCurrentEncoding)
@@ -207,14 +197,14 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
                 else
                     m_sd3->readAndPreprocess(m_pOptions->m_pEncodingC, m_pOptions->m_bAutoDetectUnicodeC);
 
-                pp.step();
+                ProgressProxy::step();
             }
 
             pTotalDiffStatus->setBinaryEqualAB(m_sd1->isBinaryEqualWith(m_sd2));
             pTotalDiffStatus->setBinaryEqualAC(m_sd1->isBinaryEqualWith(m_sd3));
             pTotalDiffStatus->setBinaryEqualBC(m_sd3->isBinaryEqualWith(m_sd2));
 
-            pp.setInformation(i18n("Diff: A <-> B"));
+            ProgressProxy::setInformation(i18n("Diff: A <-> B"));
             qCInfo(kdiffMain) << i18n("Diff: A <-> B");
 
             if(m_sd1->isText() && m_sd2->isText())
@@ -224,9 +214,9 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
 
                 m_diff3LineList.calcDiff3LineListUsingAB(&m_diffList12);
             }
-            pp.step();
+            ProgressProxy::step();
 
-            pp.setInformation(i18n("Diff: A <-> C"));
+            ProgressProxy::setInformation(i18n("Diff: A <-> C"));
             qCInfo(kdiffMain) << i18n("Diff: A <-> C");
 
             if(m_sd1->isText() && m_sd3->isText())
@@ -238,9 +228,9 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
                 m_diff3LineList.correctManualDiffAlignment(&m_manualDiffHelpList);
                 m_diff3LineList.calcDiff3LineListTrim(m_sd1->getLineDataForDiff(), m_sd2->getLineDataForDiff(), m_sd3->getLineDataForDiff(), &m_manualDiffHelpList);
             }
-            pp.step();
+            ProgressProxy::step();
 
-            pp.setInformation(i18n("Diff: B <-> C"));
+            ProgressProxy::setInformation(i18n("Diff: B <-> C"));
             qCInfo(kdiffMain) << i18n("Diff: B <-> C");
 
             if(m_sd2->isText() && m_sd3->isText())
@@ -254,7 +244,7 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
                     m_diff3LineList.calcDiff3LineListTrim(m_sd1->getLineDataForDiff(), m_sd2->getLineDataForDiff(), m_sd3->getLineDataForDiff(), &m_manualDiffHelpList);
                 }
             }
-            pp.step();
+            ProgressProxy::step();
 
             if(!m_pOptions->m_bDiff3AlignBC)
             {
@@ -263,19 +253,19 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
                 m_diff3LineList.debugLineCheck(m_sd3->getSizeLines(), e_SrcSelector::C);
             }
 
-            pp.setInformation(i18n("Linediff: A <-> B"));
+            ProgressProxy::setInformation(i18n("Linediff: A <-> B"));
             qCInfo(kdiffMain) << i18n("Linediff: A <-> B");
             if(m_sd1->hasData() && m_sd2->hasData() && m_sd1->isText() && m_sd2->isText())
                 pTotalDiffStatus->setTextEqualAB(m_diff3LineList.fineDiff(e_SrcSelector::A, m_sd1->getLineDataForDisplay(), m_sd2->getLineDataForDisplay(), eIgnoreFlags));
-            pp.step();
+            ProgressProxy::step();
 
-            pp.setInformation(i18n("Linediff: B <-> C"));
+            ProgressProxy::setInformation(i18n("Linediff: B <-> C"));
             qCInfo(kdiffMain) << i18n("Linediff: B <-> C");
             if(m_sd2->hasData() && m_sd3->hasData() && m_sd2->isText() && m_sd3->isText())
                 pTotalDiffStatus->setTextEqualBC(m_diff3LineList.fineDiff(e_SrcSelector::B, m_sd2->getLineDataForDisplay(), m_sd3->getLineDataForDisplay(), eIgnoreFlags));
-            pp.step();
+            ProgressProxy::step();
 
-            pp.setInformation(i18n("Linediff: A <-> C"));
+            ProgressProxy::setInformation(i18n("Linediff: A <-> C"));
             qCInfo(kdiffMain) << i18n("Linediff: A <-> C");
             if(m_sd1->hasData() && m_sd3->hasData() && m_sd1->isText() && m_sd3->isText())
                 pTotalDiffStatus->setTextEqualAC(m_diff3LineList.fineDiff(e_SrcSelector::C, m_sd3->getLineDataForDisplay(), m_sd1->getLineDataForDisplay(), eIgnoreFlags));
@@ -285,20 +275,20 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
                 m_diff3LineList.debugLineCheck(m_sd3->getSizeLines(), e_SrcSelector::C);
             }
 
-            pp.setInformation(i18n("Linediff: A <-> B"));
+            ProgressProxy::setInformation(i18n("Linediff: A <-> B"));
             if(m_sd1->hasData() && m_sd2->hasData() && m_sd1->isText() && m_sd2->isText())
                 pTotalDiffStatus->setTextEqualAB(m_diff3LineList.fineDiff(e_SrcSelector::A, m_sd1->getLineDataForDisplay(), m_sd2->getLineDataForDisplay(), eIgnoreFlags));
-            pp.step();
+            ProgressProxy::step();
 
-            pp.setInformation(i18n("Linediff: B <-> C"));
+            ProgressProxy::setInformation(i18n("Linediff: B <-> C"));
             if(m_sd3->hasData() && m_sd2->hasData() && m_sd3->isText() && m_sd2->isText())
                 pTotalDiffStatus->setTextEqualBC(m_diff3LineList.fineDiff(e_SrcSelector::B, m_sd2->getLineDataForDisplay(), m_sd3->getLineDataForDisplay(), eIgnoreFlags));
-            pp.step();
+            ProgressProxy::step();
 
-            pp.setInformation(i18n("Linediff: A <-> C"));
+            ProgressProxy::setInformation(i18n("Linediff: A <-> C"));
             if(m_sd1->hasData() && m_sd3->hasData() && m_sd1->isText() && m_sd3->isText())
                 pTotalDiffStatus->setTextEqualAC(m_diff3LineList.fineDiff(e_SrcSelector::C, m_sd3->getLineDataForDisplay(), m_sd1->getLineDataForDisplay(), eIgnoreFlags));
-            pp.step();
+            ProgressProxy::step();
             if(m_sd1->getSizeBytes() == 0)
             {
                 pTotalDiffStatus->setTextEqualAB(false);
@@ -315,7 +305,7 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
     }
     else
     {
-        pp.clear();
+        ProgressProxy::clear();
     }
 
     if(errors.isEmpty() && m_sd1->isText() && m_sd2->isText())
@@ -330,8 +320,8 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
     }
 
     // Calc needed lines for display
-    if(m_diff3LineList.size() <= TYPE_MAX(QtNumberType))
-        m_neededLines = SafeInt<QtNumberType>(m_diff3LineList.size());
+    if(m_diff3LineList.size() <= TYPE_MAX(qint32))
+        m_neededLines = SafeInt<qint32>(m_diff3LineList.size());
     else
     {
         errors.append("Too many lines in diff. Skiping file.");
@@ -420,7 +410,7 @@ void KDiff3App::createCaption()
     QString f1 = m_sd1->getAliasName();
     QString f2 = m_sd2->getAliasName();
     QString f3 = m_sd3->getAliasName();
-    int p;
+    qint32 p;
 
     if((p = f1.lastIndexOf('/')) >= 0 || (p = f1.lastIndexOf('\\')) >= 0)
         f1 = f1.mid(p + 1);
@@ -456,19 +446,19 @@ void KDiff3App::createCaption()
 
 void KDiff3App::setHScrollBarRange()
 {
-    int w1 = m_pDiffTextWindow1 != nullptr && m_pDiffTextWindow1->isVisible() ? m_pDiffTextWindow1->getMaxTextWidth() : 0;
-    int w2 = m_pDiffTextWindow2 != nullptr && m_pDiffTextWindow2->isVisible() ? m_pDiffTextWindow2->getMaxTextWidth() : 0;
-    int w3 = m_pDiffTextWindow3 != nullptr && m_pDiffTextWindow3->isVisible() ? m_pDiffTextWindow3->getMaxTextWidth() : 0;
+    qint32 w1 = m_pDiffTextWindow1 != nullptr && m_pDiffTextWindow1->isVisible() ? m_pDiffTextWindow1->getMaxTextWidth() : 0;
+    qint32 w2 = m_pDiffTextWindow2 != nullptr && m_pDiffTextWindow2->isVisible() ? m_pDiffTextWindow2->getMaxTextWidth() : 0;
+    qint32 w3 = m_pDiffTextWindow3 != nullptr && m_pDiffTextWindow3->isVisible() ? m_pDiffTextWindow3->getMaxTextWidth() : 0;
 
-    int wm = m_pMergeResultWindow != nullptr && m_pMergeResultWindow->isVisible() ? m_pMergeResultWindow->getMaxTextWidth() : 0;
+    qint32 wm = m_pMergeResultWindow != nullptr && m_pMergeResultWindow->isVisible() ? m_pMergeResultWindow->getMaxTextWidth() : 0;
 
-    int v1 = m_pDiffTextWindow1 != nullptr && m_pDiffTextWindow1->isVisible() ? m_pDiffTextWindow1->getVisibleTextAreaWidth() : 0;
-    int v2 = m_pDiffTextWindow2 != nullptr && m_pDiffTextWindow2->isVisible() ? m_pDiffTextWindow2->getVisibleTextAreaWidth() : 0;
-    int v3 = m_pDiffTextWindow3 != nullptr && m_pDiffTextWindow3->isVisible() ? m_pDiffTextWindow3->getVisibleTextAreaWidth() : 0;
-    int vm = m_pMergeResultWindow != nullptr && m_pMergeResultWindow->isVisible() ? m_pMergeResultWindow->getVisibleTextAreaWidth() : 0;
+    qint32 v1 = m_pDiffTextWindow1 != nullptr && m_pDiffTextWindow1->isVisible() ? m_pDiffTextWindow1->getVisibleTextAreaWidth() : 0;
+    qint32 v2 = m_pDiffTextWindow2 != nullptr && m_pDiffTextWindow2->isVisible() ? m_pDiffTextWindow2->getVisibleTextAreaWidth() : 0;
+    qint32 v3 = m_pDiffTextWindow3 != nullptr && m_pDiffTextWindow3->isVisible() ? m_pDiffTextWindow3->getVisibleTextAreaWidth() : 0;
+    qint32 vm = m_pMergeResultWindow != nullptr && m_pMergeResultWindow->isVisible() ? m_pMergeResultWindow->getVisibleTextAreaWidth() : 0;
 
     // Find the minimum, but don't consider 0.
-    int pageStep = 0;
+    qint32 pageStep = 0;
     if((pageStep == 0 || pageStep > v1) && v1 > 0)
         pageStep = v1;
     if((pageStep == 0 || pageStep > v2) && v2 > 0)
@@ -478,7 +468,7 @@ void KDiff3App::setHScrollBarRange()
     if((pageStep == 0 || pageStep > vm) && vm > 0)
         pageStep = vm;
 
-    int rangeMax = 0;
+    qint32 rangeMax = 0;
     if(w1 > v1 && w1 - v1 > rangeMax && v1 > 0)
         rangeMax = w1 - v1;
     if(w2 > v2 && w2 - v2 > rangeMax && v2 > 0)
@@ -493,18 +483,18 @@ void KDiff3App::setHScrollBarRange()
     m_pHScrollBar->setPageStep(pageStep);
 }
 
-void KDiff3App::resizeDiffTextWindowHeight(int newHeight)
+void KDiff3App::resizeDiffTextWindowHeight(qint32 newHeight)
 {
     m_DTWHeight = newHeight;
 
-    DiffTextWindow::mVScrollBar->setRange(0, std::max(0, QtNumberType(m_neededLines + 1 - newHeight)));
+    DiffTextWindow::mVScrollBar->setRange(0, std::max(0, qint32(m_neededLines + 1 - newHeight)));
     DiffTextWindow::mVScrollBar->setPageStep(newHeight);
     m_pOverview->setRange(DiffTextWindow::mVScrollBar->value(), DiffTextWindow::mVScrollBar->pageStep());
 
     setHScrollBarRange();
 }
 
-void KDiff3App::scrollDiffTextWindow(int deltaX, int deltaY)
+void KDiff3App::scrollDiffTextWindow(qint32 deltaX, qint32 deltaY)
 {
     if(deltaY != 0 && DiffTextWindow::mVScrollBar != nullptr)
     {
@@ -514,7 +504,7 @@ void KDiff3App::scrollDiffTextWindow(int deltaX, int deltaY)
         m_pHScrollBar->QScrollBar::setValue(m_pHScrollBar->value() + deltaX);
 }
 
-void KDiff3App::scrollMergeResultWindow(int deltaX, int deltaY)
+void KDiff3App::scrollMergeResultWindow(qint32 deltaX, qint32 deltaY)
 {
     if(deltaY != 0)
         MergeResultWindow::mVScrollBar->setValue(MergeResultWindow::mVScrollBar->value() + deltaY);
@@ -522,7 +512,7 @@ void KDiff3App::scrollMergeResultWindow(int deltaX, int deltaY)
         m_pHScrollBar->setValue(m_pHScrollBar->value() + deltaX);
 }
 
-void KDiff3App::sourceMask(int srcMask, int enabledMask)
+void KDiff3App::sourceMask(qint32 srcMask, qint32 enabledMask)
 {
     chooseA->blockSignals(true);
     chooseB->blockSignals(true);
@@ -618,15 +608,15 @@ void KDiff3App::initView()
 
     autoAdvance->setEnabled(true);
 
-    QList<int> sizes = pVSplitter->sizes();
-    int total = sizes[0] + sizes[1];
+    QList<qint32> sizes = pVSplitter->sizes();
+    qint32 total = sizes[0] + sizes[1];
     if(total < 10)
         total = 100;
     sizes[0] = total / 2;
     sizes[1] = total / 2;
     pVSplitter->setSizes(sizes);
 
-    QList<int> hSizes = {1, 1, 1};
+    QList<qint32> hSizes = {1, 1, 1};
 
     m_pDiffWindowSplitter->setSizes(hSizes);
 
@@ -640,16 +630,16 @@ void KDiff3App::initView()
     pHScrollBarLayout->addWidget(m_pCornerWidget);
 
     chk_connect(DiffTextWindow::mVScrollBar, &QScrollBar::valueChanged, m_pOverview, &Overview::setFirstLine);
-    chk_connect(DiffTextWindow::mVScrollBar, &QScrollBar::valueChanged, m_pDiffTextWindow1.get(), &DiffTextWindow::setFirstLine);
-    chk_connect(m_pHScrollBar, &ReversibleScrollBar::valueChanged2, m_pDiffTextWindow1.get(), &DiffTextWindow::setHorizScrollOffset);
+    chk_connect(DiffTextWindow::mVScrollBar, &QScrollBar::valueChanged, m_pDiffTextWindow1, &DiffTextWindow::setFirstLine);
+    chk_connect(m_pHScrollBar, &ReversibleScrollBar::valueChanged2, m_pDiffTextWindow1, &DiffTextWindow::setHorizScrollOffset);
     m_pDiffTextWindow1->setupConnections(this);
 
-    chk_connect(DiffTextWindow::mVScrollBar, &QScrollBar::valueChanged, m_pDiffTextWindow2.get(), &DiffTextWindow::setFirstLine);
-    chk_connect(m_pHScrollBar, &ReversibleScrollBar::valueChanged2, m_pDiffTextWindow2.get(), &DiffTextWindow::setHorizScrollOffset);
+    chk_connect(DiffTextWindow::mVScrollBar, &QScrollBar::valueChanged, m_pDiffTextWindow2, &DiffTextWindow::setFirstLine);
+    chk_connect(m_pHScrollBar, &ReversibleScrollBar::valueChanged2, m_pDiffTextWindow2, &DiffTextWindow::setHorizScrollOffset);
     m_pDiffTextWindow2->setupConnections(this);
 
-    chk_connect(DiffTextWindow::mVScrollBar, &QScrollBar::valueChanged, m_pDiffTextWindow3.get(), &DiffTextWindow::setFirstLine);
-    chk_connect(m_pHScrollBar, &ReversibleScrollBar::valueChanged2, m_pDiffTextWindow3.get(), &DiffTextWindow::setHorizScrollOffset);
+    chk_connect(DiffTextWindow::mVScrollBar, &QScrollBar::valueChanged, m_pDiffTextWindow3, &DiffTextWindow::setFirstLine);
+    chk_connect(m_pHScrollBar, &ReversibleScrollBar::valueChanged2, m_pDiffTextWindow3, &DiffTextWindow::setHorizScrollOffset);
     m_pDiffTextWindow3->setupConnections(this);
 
     MergeResultWindow* p = m_pMergeResultWindow;
@@ -660,22 +650,22 @@ void KDiff3App::initView()
     p->setupConnections(this);
     sourceMask(0, 0);
 
-    chk_connect(p, &MergeResultWindow::setFastSelectorRange, m_pDiffTextWindow1.get(), &DiffTextWindow::setFastSelectorRange);
-    chk_connect(p, &MergeResultWindow::setFastSelectorRange, m_pDiffTextWindow2.get(), &DiffTextWindow::setFastSelectorRange);
-    chk_connect(p, &MergeResultWindow::setFastSelectorRange, m_pDiffTextWindow3.get(), &DiffTextWindow::setFastSelectorRange);
-    chk_connect(m_pDiffTextWindow1.get(), &DiffTextWindow::setFastSelectorLine, p, &MergeResultWindow::slotSetFastSelectorLine);
-    chk_connect(m_pDiffTextWindow2.get(), &DiffTextWindow::setFastSelectorLine, p, &MergeResultWindow::slotSetFastSelectorLine);
-    chk_connect(m_pDiffTextWindow3.get(), &DiffTextWindow::setFastSelectorLine, p, &MergeResultWindow::slotSetFastSelectorLine);
-    chk_connect(m_pDiffTextWindow1.get(), &DiffTextWindow::gotFocus, p, &MergeResultWindow::updateSourceMask);
-    chk_connect(m_pDiffTextWindow2.get(), &DiffTextWindow::gotFocus, p, &MergeResultWindow::updateSourceMask);
-    chk_connect(m_pDiffTextWindow3.get(), &DiffTextWindow::gotFocus, p, &MergeResultWindow::updateSourceMask);
+    chk_connect(p, &MergeResultWindow::setFastSelectorRange, m_pDiffTextWindow1, &DiffTextWindow::setFastSelectorRange);
+    chk_connect(p, &MergeResultWindow::setFastSelectorRange, m_pDiffTextWindow2, &DiffTextWindow::setFastSelectorRange);
+    chk_connect(p, &MergeResultWindow::setFastSelectorRange, m_pDiffTextWindow3, &DiffTextWindow::setFastSelectorRange);
+    chk_connect(m_pDiffTextWindow1, &DiffTextWindow::setFastSelectorLine, p, &MergeResultWindow::slotSetFastSelectorLine);
+    chk_connect(m_pDiffTextWindow2, &DiffTextWindow::setFastSelectorLine, p, &MergeResultWindow::slotSetFastSelectorLine);
+    chk_connect(m_pDiffTextWindow3, &DiffTextWindow::setFastSelectorLine, p, &MergeResultWindow::slotSetFastSelectorLine);
+    chk_connect(m_pDiffTextWindow1, &DiffTextWindow::gotFocus, p, &MergeResultWindow::updateSourceMask);
+    chk_connect(m_pDiffTextWindow2, &DiffTextWindow::gotFocus, p, &MergeResultWindow::updateSourceMask);
+    chk_connect(m_pDiffTextWindow3, &DiffTextWindow::gotFocus, p, &MergeResultWindow::updateSourceMask);
     chk_connect(m_pDirectoryMergeInfo, &DirectoryMergeInfo::gotFocus, p, &MergeResultWindow::updateSourceMask);
 
-    chk_connect(m_pDiffTextWindow1.get(), &DiffTextWindow::resizeHeightChangedSignal, this, &KDiff3App::resizeDiffTextWindowHeight);
+    chk_connect(m_pDiffTextWindow1, &DiffTextWindow::resizeHeightChangedSignal, this, &KDiff3App::resizeDiffTextWindowHeight);
     // The following two connects cause the wordwrap to be recalced thrice, just to make sure. Better than forgetting one.
-    chk_connect(m_pDiffTextWindow1.get(), &DiffTextWindow::resizeWidthChangedSignal, this, &KDiff3App::postRecalcWordWrap);
-    chk_connect(m_pDiffTextWindow2.get(), &DiffTextWindow::resizeWidthChangedSignal, this, &KDiff3App::postRecalcWordWrap);
-    chk_connect(m_pDiffTextWindow3.get(), &DiffTextWindow::resizeWidthChangedSignal, this, &KDiff3App::postRecalcWordWrap);
+    chk_connect(m_pDiffTextWindow1, &DiffTextWindow::resizeWidthChangedSignal, this, &KDiff3App::postRecalcWordWrap);
+    chk_connect(m_pDiffTextWindow2, &DiffTextWindow::resizeWidthChangedSignal, this, &KDiff3App::postRecalcWordWrap);
+    chk_connect(m_pDiffTextWindow3, &DiffTextWindow::resizeWidthChangedSignal, this, &KDiff3App::postRecalcWordWrap);
 
     m_pDiffTextWindow1->setFocus();
     m_pMainWidget->setMinimumSize(50, 50);
@@ -692,15 +682,15 @@ void KDiff3App::slotFinishMainInit()
 
     setHScrollBarRange();
 
-    int newHeight = m_pDiffTextWindow1->getNofVisibleLines();
-    /*int newWidth  = m_pDiffTextWindow1->getNofVisibleColumns();*/
+    qint32 newHeight = m_pDiffTextWindow1->getNofVisibleLines();
+    /*qint32 newWidth  = m_pDiffTextWindow1->getNofVisibleColumns();*/
     m_DTWHeight = newHeight;
 
-    DiffTextWindow::mVScrollBar->setRange(0, std::max(0, QtNumberType(m_neededLines + 1 - newHeight)));
+    DiffTextWindow::mVScrollBar->setRange(0, std::max(0, qint32(m_neededLines + 1 - newHeight)));
     DiffTextWindow::mVScrollBar->setPageStep(newHeight);
     m_pOverview->setRange(DiffTextWindow::mVScrollBar->value(), DiffTextWindow::mVScrollBar->pageStep());
 
-    int d3l = -1;
+    qint32 d3l = -1;
     if(!m_manualDiffHelpList.empty())
         d3l = m_manualDiffHelpList.front().calcManualDiffFirstDiff3LineIdx(mDiff3LineVector);
 
@@ -708,7 +698,7 @@ void KDiff3App::slotFinishMainInit()
 
     if(d3l >= 0 && m_pDiffTextWindow1)
     {
-        int line = m_pDiffTextWindow1->convertDiff3LineIdxToLine(d3l);
+        qint32 line = m_pDiffTextWindow1->convertDiff3LineIdxToLine(d3l);
         DiffTextWindow::mVScrollBar->setValue(std::max(0, line - 1));
     }
     else
@@ -858,7 +848,7 @@ void KDiff3App::slotFileOpen()
 
     if(m_pDirectoryMergeWindow->isDirectoryMergeInProgress())
     {
-        int result = KMessageBox::warningYesNo(this,
+        qint32 result = KMessageBox::warningYesNo(this,
                                                i18n("You are currently doing a folder merge. Are you sure, you want to abort?"),
                                                i18nc("Error dialog caption", "Warning"),
                                                KGuiItem(i18n("Abort")),
@@ -878,7 +868,7 @@ void KDiff3App::slotFileOpen()
                      m_bDirCompare ? !gDirInfo->destDir().prettyAbsPath().isEmpty() : !m_outputFilename.isEmpty(),
                      QDir::toNativeSeparators(m_bDefaultFilename ? QString("") : m_outputFilename), m_pOptionDialog->getOptions()));
 
-        int status = d->exec();
+        qint32 status = d->exec();
         if(status == QDialog::Accepted)
         {
             m_sd1->setFilename(d->getFileA());
@@ -1170,7 +1160,7 @@ void KDiff3App::slotGoToLine()
                 ([&pDialog, pLineNumEdit]() {
                     if(pLineNumEdit->text() != "")
                     {
-                        int lineNum = pLineNumEdit->text().toInt();
+                        qint32 lineNum = pLineNumEdit->text().toInt();
                         lineNum = qMax(lineNum - 2, 0);
                         //No need for anything else here setValue triggers a valueChanged signal internally.
                         DiffTextWindow::mVScrollBar->setValue(lineNum);
@@ -1249,7 +1239,7 @@ void KDiff3App::slotSplitDiff()
 {
     LineRef firstLine;
     LineRef lastLine;
-    std::shared_ptr<DiffTextWindow> pDTW = nullptr;
+    QPointer<DiffTextWindow> pDTW = nullptr;
     if(m_pDiffTextWindow1)
     {
         pDTW = m_pDiffTextWindow1;
@@ -1277,7 +1267,7 @@ void KDiff3App::slotJoinDiffs()
 {
     LineRef firstLine;
     LineRef lastLine;
-    std::shared_ptr<DiffTextWindow> pDTW = nullptr;
+    DiffTextWindow* pDTW = nullptr;
     if(m_pDiffTextWindow1)
     {
         pDTW = m_pDiffTextWindow1;
@@ -1335,9 +1325,9 @@ void KDiff3App::slotSelectionStart()
 {
     const QObject* s = sender();
 
-    if(m_pDiffTextWindow1 && s != m_pDiffTextWindow1.get()) m_pDiffTextWindow1->resetSelection();
-    if(m_pDiffTextWindow2 && s != m_pDiffTextWindow2.get()) m_pDiffTextWindow2->resetSelection();
-    if(m_pDiffTextWindow3 && s != m_pDiffTextWindow3.get()) m_pDiffTextWindow3->resetSelection();
+    if(m_pDiffTextWindow1 && s != m_pDiffTextWindow1) m_pDiffTextWindow1->resetSelection();
+    if(m_pDiffTextWindow2 && s != m_pDiffTextWindow2) m_pDiffTextWindow2->resetSelection();
+    if(m_pDiffTextWindow3 && s != m_pDiffTextWindow3) m_pDiffTextWindow3->resetSelection();
     if(m_pMergeResultWindow && s != m_pMergeResultWindow) m_pMergeResultWindow->resetSelection();
 }
 
@@ -1415,6 +1405,7 @@ void KDiff3App::postRecalcWordWrap()
 {
     if(!m_bRecalcWordWrapPosted)
     {
+        while(DiffTextWindow::maxThreads() > 0) {} //Clear wordwrap threads.
         m_bRecalcWordWrapPosted = true;
         m_firstD3LIdx = -1;
         Q_EMIT sigRecalcWordWrap();
@@ -1431,7 +1422,7 @@ void KDiff3App::slotRecalcWordWrap()
 }
 
 // visibleTextWidthForPrinting is >=0 only for printing, otherwise the really visible width is used
-void KDiff3App::recalcWordWrap(int visibleTextWidthForPrinting)
+void KDiff3App::recalcWordWrap(qint32 visibleTextWidthForPrinting)
 {
     m_bRecalcWordWrapPosted = true;
     mainWindowEnable(false);
@@ -1439,8 +1430,10 @@ void KDiff3App::recalcWordWrap(int visibleTextWidthForPrinting)
     if(m_firstD3LIdx < 0)
     {
         m_firstD3LIdx = 0;
-        if(m_pDiffTextWindow1)
-            m_firstD3LIdx = m_pDiffTextWindow1->convertLineToDiff3LineIdx(m_pDiffTextWindow1->getFirstLine());
+        if(!m_pDiffTextWindow1)
+            return; //Nothing that happens from here on makes any sense if we don't have a DiffTextWindow.
+
+        m_firstD3LIdx = m_pDiffTextWindow1->convertLineToDiff3LineIdx(m_pDiffTextWindow1->getFirstLine());
     }
 
     // Convert selection to D3L-coords (converting back happens in DiffTextWindow::recalcWordWrap()
@@ -1501,8 +1494,10 @@ void KDiff3App::recalcWordWrap(int visibleTextWidthForPrinting)
     }
 }
 
-void KDiff3App::slotFinishRecalcWordWrap(int visibleTextWidthForPrinting)
+void KDiff3App::slotFinishRecalcWordWrap(qint32 visibleTextWidthForPrinting)
 {
+    assert(m_firstD3LIdx >= 0);
+
     if(mRunnablesStarted)
     {
         ProgressProxy::endBackgroundTask();
@@ -1562,7 +1557,7 @@ void KDiff3App::slotFinishRecalcWordWrap(int visibleTextWidthForPrinting)
         if(m_pOverview)
             m_pOverview->slotRedraw();
         if(DiffTextWindow::mVScrollBar)
-            DiffTextWindow::mVScrollBar->setRange(0, std::max(0, QtNumberType(m_neededLines + 1 - m_DTWHeight)));
+            DiffTextWindow::mVScrollBar->setRange(0, std::max(0, qint32(m_neededLines + 1 - m_DTWHeight)));
         if(m_pDiffTextWindow1)
         {
             if(DiffTextWindow::mVScrollBar)
@@ -1708,7 +1703,7 @@ bool KDiff3App::canContinue()
     // First test if anything must be saved.
     if(m_bOutputModified)
     {
-        int result = KMessageBox::warningYesNoCancel(this,
+        qint32 result = KMessageBox::warningYesNoCancel(this,
                                                      i18n("The merge result has not been saved."),
                                                      i18nc("Error dialog caption", "Warning"),
                                                      KGuiItem(i18n("Save && Continue")),
@@ -1838,9 +1833,9 @@ void KDiff3App::slotEditFindNext()
     bool bCaseSensitive = m_pFindDialog->m_pCaseSensitive->isChecked();
 
     LineRef d3vLine = m_pFindDialog->currentLine;
-    int posInLine = m_pFindDialog->currentPos;
+    qint32 posInLine = m_pFindDialog->currentPos;
     LineRef l;
-    int p = 0;
+    qint32 p = 0;
     if(m_pFindDialog->getCurrentWindow() == eWindowIndex::A)
     {
         if(m_pFindDialog->m_pSearchInA->isChecked() && m_pDiffTextWindow1 != nullptr &&
@@ -1957,9 +1952,9 @@ void KDiff3App::slotWinFocusNext()
     }
 
     std::list<QWidget*> visibleWidgetList;
-    if(m_pDiffTextWindow1 && m_pDiffTextWindow1->isVisible()) visibleWidgetList.push_back(m_pDiffTextWindow1.get());
-    if(m_pDiffTextWindow2 && m_pDiffTextWindow2->isVisible()) visibleWidgetList.push_back(m_pDiffTextWindow2.get());
-    if(m_pDiffTextWindow3 && m_pDiffTextWindow3->isVisible()) visibleWidgetList.push_back(m_pDiffTextWindow3.get());
+    if(m_pDiffTextWindow1 && m_pDiffTextWindow1->isVisible()) visibleWidgetList.push_back(m_pDiffTextWindow1);
+    if(m_pDiffTextWindow2 && m_pDiffTextWindow2->isVisible()) visibleWidgetList.push_back(m_pDiffTextWindow2);
+    if(m_pDiffTextWindow3 && m_pDiffTextWindow3->isVisible()) visibleWidgetList.push_back(m_pDiffTextWindow3);
     if(m_pMergeResultWindow && m_pMergeResultWindow->isVisible()) visibleWidgetList.push_back(m_pMergeResultWindow);
     if(m_bDirCompare /*m_pDirectoryMergeWindow->isVisible()*/) visibleWidgetList.push_back(m_pDirectoryMergeWindow);
     //if ( m_pDirectoryMergeInfo->isVisible() ) visibleWidgetList.push_back(m_pDirectoryMergeInfo->getInfoList());
@@ -1987,9 +1982,9 @@ void KDiff3App::slotWinFocusPrev()
     }
 
     std::list<QWidget*> visibleWidgetList;
-    if(m_pDiffTextWindow1 && m_pDiffTextWindow1->isVisible()) visibleWidgetList.push_back(m_pDiffTextWindow1.get());
-    if(m_pDiffTextWindow2 && m_pDiffTextWindow2->isVisible()) visibleWidgetList.push_back(m_pDiffTextWindow2.get());
-    if(m_pDiffTextWindow3 && m_pDiffTextWindow3->isVisible()) visibleWidgetList.push_back(m_pDiffTextWindow3.get());
+    if(m_pDiffTextWindow1 && m_pDiffTextWindow1->isVisible()) visibleWidgetList.push_back(m_pDiffTextWindow1);
+    if(m_pDiffTextWindow2 && m_pDiffTextWindow2->isVisible()) visibleWidgetList.push_back(m_pDiffTextWindow2);
+    if(m_pDiffTextWindow3 && m_pDiffTextWindow3->isVisible()) visibleWidgetList.push_back(m_pDiffTextWindow3);
     if(m_pMergeResultWindow && m_pMergeResultWindow->isVisible()) visibleWidgetList.push_back(m_pMergeResultWindow);
     if(m_bDirCompare /* m_pDirectoryMergeWindow->isVisible() */) visibleWidgetList.push_back(m_pDirectoryMergeWindow);
     //if ( m_pDirectoryMergeInfo->isVisible() ) visibleWidgetList.push_back(m_pDirectoryMergeInfo->getInfoList());
