@@ -1,3 +1,4 @@
+// clang-format off
 /*
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -11,6 +12,7 @@
 
 #include "common.h"
 #include "defmac.h"
+#include "difftextwindow.h"
 
 #include <cmath>
 
@@ -31,7 +33,7 @@
 
 namespace placeholders = boost::placeholders;
 
-std::shared_ptr<ProgressDialog> g_pProgressDialog = nullptr;
+QPointer<ProgressDialog> g_pProgressDialog = nullptr;
 
 ProgressDialog::ProgressDialog(QWidget* pParent, QStatusBar* pStatusBar)
     : QDialog(pParent), m_pStatusBar(pStatusBar)
@@ -69,6 +71,11 @@ ProgressDialog::ProgressDialog(QWidget* pParent, QStatusBar* pStatusBar)
     initConnections();
 }
 
+ProgressDialog::~ProgressDialog()
+{
+    while(DiffTextWindow::maxThreads() > 0) {} //expected to be set by last helper thread.
+}
+
 void ProgressDialog::initConnections()
 {
     connections.push_back(ProgressProxy::startBackgroundTask.connect(boost::bind(&ProgressDialog::beginBackgroundTask, this)));
@@ -76,20 +83,20 @@ void ProgressDialog::initConnections()
 
     connections.push_back(ProgressProxy::push.connect(boost::bind(&ProgressDialog::push, this)));
     connections.push_back(ProgressProxy::pop.connect(boost::bind(&ProgressDialog::pop, this, placeholders::_1)));
-    connections.push_back(ProgressProxy::clearSig.connect(boost::bind(&ProgressDialog::clear, this)));
+    connections.push_back(ProgressProxy::clear.connect(boost::bind(&ProgressDialog::clear, this)));
 
     connections.push_back(ProgressProxy::enterEventLoop.connect(boost::bind(&ProgressDialog::enterEventLoop, this, placeholders::_1, placeholders::_2)));
     connections.push_back(ProgressProxy::exitEventLoop.connect(boost::bind(&ProgressDialog::exitEventLoop, this)));
 
     connections.push_back(ProgressProxy::setCurrentSig.connect(boost::bind(&ProgressDialog::setCurrent, this, placeholders::_1, placeholders::_2)));
-    connections.push_back(ProgressProxy::addNofStepsSig.connect(boost::bind(&ProgressDialog::addNofSteps, this, placeholders::_1)));
-    connections.push_back(ProgressProxy::setMaxNofStepsSig.connect(boost::bind(&ProgressDialog::setMaxNofSteps, this, placeholders::_1)));
+    connections.push_back(ProgressProxy::addNofSteps.connect(boost::bind(&ProgressDialog::addNofSteps, this, placeholders::_1)));
+    connections.push_back(ProgressProxy::setMaxNofSteps.connect(boost::bind(&ProgressDialog::setMaxNofSteps, this, placeholders::_1)));
     connections.push_back(ProgressProxy::stepSig.connect(boost::bind(&ProgressDialog::step, this, placeholders::_1)));
 
-    connections.push_back(ProgressProxy::setRangeTransformationSig.connect(boost::bind(&ProgressDialog::setRangeTransformation, this, placeholders::_1, placeholders::_2)));
-    connections.push_back(ProgressProxy::setSubRangeTransformationSig.connect(boost::bind(&ProgressDialog::setSubRangeTransformation, this, placeholders::_1, placeholders::_2)));
+    connections.push_back(ProgressProxy::setRangeTransformation.connect(boost::bind(&ProgressDialog::setRangeTransformation, this, placeholders::_1, placeholders::_2)));
+    connections.push_back(ProgressProxy::setSubRangeTransformation.connect(boost::bind(&ProgressDialog::setSubRangeTransformation, this, placeholders::_1, placeholders::_2)));
 
-    connections.push_back(ProgressProxy::wasCancelledSig.connect(boost::bind(&ProgressDialog::wasCancelled, this)));
+    connections.push_back(ProgressProxy::wasCancelled.connect(boost::bind(&ProgressDialog::wasCancelled, this)));
 
     connections.push_back(ProgressProxy::setInformationSig.connect(boost::bind(
         static_cast<void (ProgressDialog::*)(const QString&, bool)>(&ProgressDialog::setInformation),
@@ -187,7 +194,7 @@ void ProgressDialog::pop(bool bRedrawUpdate)
     }
 }
 
-void ProgressDialog::setInformation(const QString& info, int current, bool bRedrawUpdate)
+void ProgressDialog::setInformation(const QString& info, qint32 current, bool bRedrawUpdate)
 {
     if(m_progressStack.empty())
         return;
@@ -221,7 +228,7 @@ void ProgressDialog::setInformationImp(const QString& info)
 #ifndef AUTOTEST
     assert(!m_progressStack.empty());
 
-    int level = m_progressStack.size();
+    qint32 level = m_progressStack.size();
     if(level == 1)
     {
         dialogUi.information->setText(info);
@@ -359,7 +366,7 @@ void ProgressDialog::recalc(bool bUpdate)
             if(!m_bStayHidden)
                 m_progressDelayTimer = startTimer(3000); /* 3 s delay */
 
-            int level = m_progressStack.size();
+            qint32 level = m_progressStack.size();
             if((bUpdate && level == 1) || m_t1.elapsed() > 200)
             {
                 if(m_progressStack.empty())
@@ -370,16 +377,16 @@ void ProgressDialog::recalc(bool bUpdate)
                 else
                 {
                     QList<ProgressLevelData>::iterator i = m_progressStack.begin();
-                    int value = int(1000.0 * (getAtomic(i->m_current) * (i->m_dRangeMax - i->m_dRangeMin) / getAtomic(i->m_maxNofSteps) + i->m_dRangeMin));
+                    qint32 value = qint32(1000.0 * (getAtomic(i->m_current) * (i->m_dRangeMax - i->m_dRangeMin) / getAtomic(i->m_maxNofSteps) + i->m_dRangeMin));
                     dialogUi.progressBar->setValue(value);
                     if(m_bStayHidden && m_pStatusProgressBar)
                         m_pStatusProgressBar->setValue(value);
 
                     ++i;
                     if(i != m_progressStack.end())
-                        dialogUi.subProgressBar->setValue((int)lround(1000.0 * (getAtomic(i->m_current) * (i->m_dRangeMax - i->m_dRangeMin) / getAtomic(i->m_maxNofSteps) + i->m_dRangeMin)));
+                        dialogUi.subProgressBar->setValue((qint32)lround(1000.0 * (getAtomic(i->m_current) * (i->m_dRangeMax - i->m_dRangeMin) / getAtomic(i->m_maxNofSteps) + i->m_dRangeMin)));
                     else
-                        dialogUi.subProgressBar->setValue((int)lround(1000.0 * m_progressStack.front().m_dSubRangeMin));
+                        dialogUi.subProgressBar->setValue((qint32)lround(1000.0 * m_progressStack.front().m_dSubRangeMin));
                 }
 
                 if(!m_bStayHidden && !isVisible())
