@@ -24,21 +24,19 @@ class QLabel;
 class QProgressBar;
 class QStatusBar;
 
-/*
-    Due to Qt/automoc wonkyness multiple inhertance can not be used with by this class.
-*/
 class ProgressDialog: public QDialog
 {
     Q_OBJECT
   public:
     ProgressDialog(QWidget* pParent, QStatusBar*);
+     ~ProgressDialog() override;
 
     void beginBackgroundTask();
     void endBackgroundTask();
 
     void setStayHidden(bool bStayHidden);
     void setInformation(const QString& info, bool bRedrawUpdate = true);
-    void setInformation(const QString& info, int current, bool bRedrawUpdate = true);
+    void setInformation(const QString& info, qint32 current, bool bRedrawUpdate = true);
     void setCurrent(qint64 current, bool bRedrawUpdate = true);
     void step(bool bRedrawUpdate = true);
     void clear();
@@ -60,6 +58,7 @@ class ProgressDialog: public QDialog
     bool wasCancelled();
     enum e_CancelReason
     {
+        eExit,
         eUserAbort,
         eResize
     };
@@ -102,9 +101,9 @@ class ProgressDialog: public QDialog
     quint64 backgroundTaskCount = 0;
     QList<ProgressLevelData> m_progressStack;
 
-    int m_progressDelayTimer = 0;
-    int m_delayedHideTimer = 0;
-    int m_delayedHideStatusBarWidgetTimer = 0;
+    qint32 m_progressDelayTimer = 0;
+    qint32 m_delayedHideTimer = 0;
+    qint32 m_delayedHideStatusBarWidgetTimer = 0;
     QPointer<QEventLoop> m_eventLoop;
 
     QElapsedTimer m_t1;
@@ -125,6 +124,6 @@ class ProgressDialog: public QDialog
     std::list<boost::signals2::scoped_connection> connections;
 };
 
-extern std::shared_ptr<ProgressDialog> g_pProgressDialog;
+extern QPointer<ProgressDialog> g_pProgressDialog;
 
 #endif
