@@ -4,13 +4,15 @@
  * SPDX-FileCopyrightText: 2002-2011 Joachim Eibl, joachim.eibl at gmx.de
  * SPDX-FileCopyrightText: 2018-2020 Michael Reeves reeves.87@gmail.com
  * SPDX-License-Identifier: GPL-2.0-or-later
-*/
+ */
+// clang-format on
 #ifndef SELECTION_H
 #define SELECTION_H
 
 #include "LineRef.h"
 
 #include <algorithm>  // for max, min
+#include <QtGlobal>
 
 class Selection
 {
@@ -20,8 +22,8 @@ private:
   LineRef firstLine;
   LineRef lastLine;
 
-  int firstPos = -1;
-  int lastPos = -1;
+  qint32 firstPos = -1;
+  qint32 lastPos = -1;
 
   LineRef oldFirstLine;
   LineRef oldLastLine;
@@ -29,19 +31,19 @@ public:
 //private:
   bool bSelectionContainsData = false;
 public:
-  inline LineRef getFirstLine() const { return firstLine; };
-  inline LineRef getLastLine() const { return lastLine; };
+  [[nodiscard]] inline LineRef getFirstLine() const { return firstLine; };
+  [[nodiscard]] inline LineRef getLastLine() const { return lastLine; };
 
-  inline int getFirstPos() const { return firstPos; };
-  inline int getLastPos() const { return lastPos; };
+  [[nodiscard]] inline qint32 getFirstPos() const { return firstPos; };
+  [[nodiscard]] inline qint32 getLastPos() const { return lastPos; };
 
   inline bool isValidFirstLine() { return firstLine.isValid(); }
   inline void clearOldSelection() { oldLastLine.invalidate(), oldFirstLine.invalidate(); };
 
-  inline LineRef getOldLastLine() const { return oldLastLine; };
-  inline LineRef getOldFirstLine() const  { return oldFirstLine; };
-  inline bool selectionContainsData() const { return bSelectionContainsData; };
-  bool isEmpty() const { return !firstLine.isValid() || (firstLine == lastLine && firstPos == lastPos) || !bSelectionContainsData; }
+  [[nodiscard]] inline LineRef getOldLastLine() const { return oldLastLine; };
+  [[nodiscard]] inline LineRef getOldFirstLine() const  { return oldFirstLine; };
+  [[nodiscard]] inline bool selectionContainsData() const { return bSelectionContainsData; };
+  [[nodiscard]] bool isEmpty() const { return !firstLine.isValid() || (firstLine == lastLine && firstPos == lastPos) || !bSelectionContainsData; }
   void reset()
   {
       oldLastLine = lastLine;
@@ -50,35 +52,35 @@ public:
       lastLine.invalidate();
       bSelectionContainsData = false;
    }
-   void start( LineRef l, int p ) { firstLine = l; firstPos = p; }
-   void end( LineRef l, int p )  {
+   void start( LineRef l, qint32 p ) { firstLine = l; firstPos = p; }
+   void end( LineRef l, qint32 p )  {
       if ( !oldLastLine.isValid() )
          oldLastLine = lastLine;
       lastLine  = l;
       lastPos  = p;
       //bSelectionContainsData = (firstLine == lastLine && firstPos == lastPos);
    }
-   bool within( LineRef l, LineRef p ) const;
+   [[nodiscard]] bool within( LineRef l, qint32 p ) const;
 
-   bool lineWithin( LineRef l ) const;
-   int firstPosInLine(LineRef l) const;
-   int lastPosInLine(LineRef l) const;
+   [[nodiscard]] bool lineWithin( LineRef l ) const;
+   [[nodiscard]] qint32 firstPosInLine(LineRef l) const;
+   [[nodiscard]] qint32 lastPosInLine(LineRef l) const;
 
-   LineRef beginLine() const
+   [[nodiscard]] LineRef beginLine() const
    {
       if (!firstLine.isValid() && !lastLine.isValid()) return LineRef();
       return std::max((LineRef)0,std::min(firstLine,lastLine));
    }
 
-   LineRef endLine() const
+   [[nodiscard]] LineRef endLine() const
    {
       if (!firstLine.isValid() && !lastLine.isValid()) return LineRef();
       return std::max(firstLine,lastLine);
    }
 
-   int beginPos() const { return firstLine==lastLine ? std::min(firstPos,lastPos) :
+   [[nodiscard]] qint32 beginPos() const { return firstLine==lastLine ? std::min(firstPos,lastPos) :
                            firstLine<lastLine ? (!firstLine.isValid()?0:firstPos) : (!lastLine.isValid()?0:lastPos);  }
-   int endPos() const { return firstLine==lastLine ? std::max(firstPos,lastPos) :
+   [[nodiscard]] qint32 endPos() const { return firstLine==lastLine ? std::max(firstPos,lastPos) :
                            firstLine<lastLine ? lastPos : firstPos;      }
 };
 
