@@ -139,7 +139,7 @@ OpenDialog::OpenDialog(
     dialogUi.lineOut->setLineEdit(new FileNameLineEdit(dialogUi.lineOut));
 }
 
-void OpenDialog::selectURL(QComboBox* pLine, bool bDir, int i, bool bSave)
+void OpenDialog::selectURL(QComboBox* pLine, bool bDir, qint32 i, bool bSave)
 {
     QString current = pLine->currentText();
     QUrl currentUrl;
@@ -182,7 +182,7 @@ void OpenDialog::selectDirB() { selectURL(dialogUi.lineB, true, 2, false); }
 void OpenDialog::selectDirC() { selectURL(dialogUi.lineC, true, 3, false); }
 void OpenDialog::selectOutputDir() { selectURL(dialogUi.lineOut, true, 4, true); }
 
-void OpenDialog::internalSlot(int i)
+void OpenDialog::internalSlot(qint32 i)
 {
     Q_EMIT internalSignal(i != 0);
 }
@@ -202,7 +202,7 @@ void OpenDialog::inputFilenameChanged()
 void OpenDialog::fixCurrentText(QComboBox* pCB)
 {
     QString s = pCB->currentText();
-    QtNumberType pos = s.indexOf('\n');
+    qint32 pos = s.indexOf('\n');
 
     if(pos >= 0)
         s = s.left(pos);
@@ -215,7 +215,7 @@ void OpenDialog::fixCurrentText(QComboBox* pCB)
 
 void OpenDialog::accept()
 {
-    int maxNofRecentFiles = 10;
+    qint32 maxNofRecentFiles = 10;
     fixCurrentText(dialogUi.lineA);
 
     QString s = dialogUi.lineA->currentText();
@@ -255,7 +255,7 @@ void OpenDialog::accept()
 
 void OpenDialog::slotSwapCopyNames(QAction* pAction) const // id selected in the popup menu
 {
-    QtNumberType id = pAction->parentWidget()->actions().indexOf(pAction);
+    qint32 id = pAction->parentWidget()->actions().indexOf(pAction);
     QComboBox* cb1 = nullptr;
     QComboBox* cb2 = nullptr;
 
@@ -320,7 +320,7 @@ FindDialog::FindDialog(QWidget* pParent)
     layout->setContentsMargins(5, 5, 5, 5);
     layout->setSpacing(5);
 
-    int line = 0;
+    qint32 line = 0;
     layout->addWidget(new QLabel(i18n("Search text:"), this), line, 0, 1, 2);
     ++line;
 
@@ -378,7 +378,7 @@ RegExpTester::RegExpTester(QWidget* pParent, const QString& autoMergeRegExpToolT
                            const QString& historyStartRegExpToolTip, const QString& historyEntryStartRegExpToolTip, const QString& historySortKeyOrderToolTip)
     : QDialog(pParent)
 {
-    int line = 0;
+    qint32 line = 0;
     setWindowTitle(i18n("Regular Expression Tester"));
     QGridLayout* pGrid = new QGridLayout(this);
     pGrid->setSpacing(5);
